@@ -11,8 +11,7 @@ from django.template.loader import render_to_string
 import lfs.core.utils
 from lfs import shipping
 from lfs.caching.utils import lfs_get_object_or_404
-from lfs.core.models import Country
-from lfs.core.models import Shop
+from lfs.core.models import Shop, Country
 from lfs.criteria.models.criteria_objects import CriteriaObjects
 from lfs.criteria.settings import EQUAL
 from lfs.criteria.settings import LESS_THAN
@@ -25,6 +24,7 @@ from lfs.criteria.settings import IS, IS_NOT, IS_VALID, IS_NOT_VALID
 from lfs.payment.models import PaymentMethod
 from lfs.shipping.models import ShippingMethod
 
+
 class Criterion(object):
     """Base class for all lfs criteria.
     """
@@ -38,12 +38,13 @@ class Criterion(object):
         template = "manage/criteria/%s_criterion.html" % self.content_type
 
         return render_to_string(template, RequestContext(request, {
-            "id" : "ex%s" % self.id,
-            "operator" : self.operator,
-            "value" : self.value,
-            "position" : position,
+            "id": "ex%s" % self.id,
+            "operator": self.operator,
+            "value": self.value,
+            "position": position,
         }))
 
+
 class CartPriceCriterion(models.Model, Criterion):
     """A criterion for the cart price.
     """
@@ -75,7 +76,7 @@ class CartPriceCriterion(models.Model, Criterion):
         the cart.
         """
         if product is not None:
-            cart_price = product.get_price()
+            cart_price = product.get_price(request)
         else:
             from lfs.cart import utils as cart_utils
             cart = cart_utils.get_cart(request)
@@ -83,7 +84,7 @@ class CartPriceCriterion(models.Model, Criterion):
             if cart is None:
                 return False
 
-            cart_price = cart_utils.get_cart_price(request, cart)
+            cart_price = cart.get_price_gross(request)
 
         if self.operator == LESS_THAN and (cart_price < self.price):
             return True
@@ -104,6 +105,7 @@ class CartPriceCriterion(models.Model, Criterion):
         """
         return self.price
 
+
 class CombinedLengthAndGirthCriterion(models.Model, Criterion):
     """A criterion for the combined length and girth.
     """
@@ -146,7 +148,7 @@ class CombinedLengthAndGirthCriterion(models.Model, Criterion):
             max_width = 0
             max_length = 0
             total_height = 0
-            for item in cart.items():
+            for item in cart.get_items():
                 if max_length < item.product.get_length():
                     max_length = item.product.get_length()
 
@@ -155,7 +157,7 @@ class CombinedLengthAndGirthCriterion(models.Model, Criterion):
 
                 total_height += item.product.get_height()
 
-            clag = (2 * max_width) +  (2 * total_height) + max_length
+            clag = (2 * max_width) + (2 * total_height) + max_length
 
         if self.operator == LESS_THAN and (clag < self.clag):
             return True
@@ -176,6 +178,7 @@ class CombinedLengthAndGirthCriterion(models.Model, Criterion):
         """
         return self.clag
 
+
 class CountryCriterion(models.Model, Criterion):
     """A criterion for the shipping country.
     """
@@ -226,7 +229,7 @@ class CountryCriterion(models.Model, Criterion):
         shop = lfs_get_object_or_404(Shop, pk=1)
 
         countries = []
-        for country in shop.countries.all():
+        for country in shop.shipping_countries.all():
             if country in self.countries.all():
                 selected = True
             else:
@@ -234,18 +237,19 @@ class CountryCriterion(models.Model, Criterion):
 
             countries.append({
                 "id" : country.id,
-                "name" : country.name,
-                "selected" : selected,
+                "name": country.name,
+                "selected": selected,
             })
 
         return render_to_string("manage/criteria/country_criterion.html", RequestContext(request, {
-            "id" : "ex%s" % self.id,
-            "operator" : self.operator,
-            "value" : self.value,
-            "position" : position,
-            "countries" : countries,
+            "id": "ex%s" % self.id,
+            "operator": self.operator,
+            "value": self.value,
+            "position": position,
+            "countries": countries,
         }))
 
+
 class HeightCriterion(models.Model, Criterion):
     """
     """
@@ -285,7 +289,7 @@ class HeightCriterion(models.Model, Criterion):
                 return False
 
             cart_height = 0
-            for item in cart.items():
+            for item in cart.get_items():
                 cart_height += (item.product.get_height() * item.amount)
 
         if self.operator == LESS_THAN and (cart_height < self.height):
@@ -307,6 +311,7 @@ class HeightCriterion(models.Model, Criterion):
         """
         return self.height
 
+
 class LengthCriterion(models.Model, Criterion):
     """A criterion for the length.
     """
@@ -346,7 +351,7 @@ class LengthCriterion(models.Model, Criterion):
                 return False
 
             max_length = 0
-            for item in cart.items():
+            for item in cart.get_items():
                 if max_length < item.product.get_length():
                     max_length = item.product.get_length()
 
@@ -369,6 +374,7 @@ class LengthCriterion(models.Model, Criterion):
         """
         return self.length
 
+
 class PaymentMethodCriterion(models.Model, Criterion):
     """A criterion for the payment method.
     """
@@ -449,19 +455,20 @@ class PaymentMethodCriterion(models.Model, Criterion):
                 selected = False
 
             payment_methods.append({
-                "id" : pm.id,
-                "name" : pm.name,
-                "selected" : selected,
+                "id": pm.id,
+                "name": pm.name,
+                "selected": selected,
             })
 
         return render_to_string("manage/criteria/payment_method_criterion.html", RequestContext(request, {
-            "id" : "ex%s" % self.id,
-            "operator" : self.operator,
-            "value" : self.value,
-            "position" : position,
-            "payment_methods" : payment_methods,
+            "id": "ex%s" % self.id,
+            "operator": self.operator,
+            "value": self.value,
+            "position": position,
+            "payment_methods": payment_methods,
         }))
 
+
 class ShippingMethodCriterion(models.Model, Criterion):
     """A criterion for the shipping method.
     """
@@ -549,19 +556,20 @@ class ShippingMethodCriterion(models.Model, Criterion):
                 selected = False
 
             shipping_methods.append({
-                "id" : sm.id,
-                "name" : sm.name,
-                "selected" : selected,
+                "id": sm.id,
+                "name": sm.name,
+                "selected": selected,
             })
 
         return render_to_string("manage/criteria/shipping_method_criterion.html", RequestContext(request, {
-            "id" : "ex%s" % self.id,
-            "operator" : self.operator,
-            "value" : self.value,
-            "position" : position,
-            "shipping_methods" : shipping_methods,
+            "id": "ex%s" % self.id,
+            "operator": self.operator,
+            "value": self.value,
+            "position": position,
+            "shipping_methods": shipping_methods,
         }))
 
+
 class UserCriterion(models.Model, Criterion):
     """A criterion for user content objects
     """
@@ -593,6 +601,7 @@ class UserCriterion(models.Model, Criterion):
         """
         return self.users
 
+
 class WeightCriterion(models.Model, Criterion):
     """
     """
@@ -633,7 +642,7 @@ class WeightCriterion(models.Model, Criterion):
                 return False
 
             cart_weight = 0
-            for item in cart.items():
+            for item in cart.get_items():
                 cart_weight += (item.product.get_weight() * item.amount)
 
         if self.operator == LESS_THAN and (cart_weight < self.weight):
@@ -655,6 +664,7 @@ class WeightCriterion(models.Model, Criterion):
         """
         return self.weight
 
+
 class WidthCriterion(models.Model, Criterion):
     """
     """
@@ -694,7 +704,7 @@ class WidthCriterion(models.Model, Criterion):
                 return False
 
             max_width = 0
-            for item in cart.items():
+            for item in cart.get_items():
                 if max_width < item.product.get_width():
                     max_width = item.product.get_width()
 
@@ -717,6 +727,7 @@ class WidthCriterion(models.Model, Criterion):
         """
         return self.width
 
+
 class DistanceCriterion(models.Model, Criterion):
     """
     """
