@@ -1,6 +1,5 @@
 # django imports
 from django.contrib.auth.decorators import permission_required
-from django.contrib.auth.models import AnonymousUser
 from django.core.exceptions import ObjectDoesNotExist
 from django.core.urlresolvers import reverse
 from django.http import HttpResponse
@@ -17,7 +16,10 @@ from lfs.catalog.models import Image
 from lfs.catalog.models import Product
 from lfs.core.signals import product_changed
 from lfs.core.utils import LazyEncoder
-from lfs.manage.utils import get_user_from_session_key
+
+# Load logger
+import logging
+logger = logging.getLogger("default")
 
 @permission_required("core.manage_shop", login_url="/login/")
 def manage_images(request, product_id, as_string=False, template_name="manage/product/images.html"):
@@ -26,40 +28,45 @@ def manage_images(request, product_id, as_string=False, template_name="manage/pr
     product = lfs_get_object_or_404(Product, pk=product_id)
 
     result = render_to_string(template_name, RequestContext(request, {
-        "product" : product,
+        "product": product,
     }))
 
     if as_string:
         return result
     else:
         result = simplejson.dumps({
-            "images" : result,
-            "message" : _(u"Images has been added."),
-        }, cls = LazyEncoder)
+            "images": result,
+            "message": _(u"Images has been added."),
+        }, cls=LazyEncoder)
 
         return HttpResponse(result)
 
 
 # Actions
+# @permission_required("core.manage_shop", login_url="/login/")
 def add_image(request, product_id):
     """Adds an image to product with passed product_id.
     """
-    user = get_user_from_session_key(request.POST.get("sessionid"))
-    if not user.has_perm("core.manage_shop"):
-        return HttpResponseRedirect("/login/")
     product = lfs_get_object_or_404(Product, pk=product_id)
     if request.method == "POST":
-        for file_content in request.FILES.values():
+        for file_content in request.FILES.getlist("file"):
             image = Image(content=product, title=file_content.name)
-            image.image.save(file_content.name, file_content, save=True)
+            try:
+                image.image.save(file_content.name, file_content, save=True)
+            except Exception, e:
+                logger.info("Upload image: %s %s" % (file_content.name, e))
+                continue
 
     # Refresh positions
     for i, image in enumerate(product.images.all()):
-        image.position = i+1
+        image.position = (i + 1) * 10
         image.save()
 
     product_changed.send(product, request=request)
-    return HttpResponse(manage_images(request, product_id, as_string=True))
+
+    result = simplejson.dumps({"name": file_content.name, "type": "image/jpeg", "size": "123456789"})
+    return HttpResponse(result)
+
 
 @permission_required("core.manage_shop", login_url="/login/")
 def update_images(request, product_id):
@@ -103,18 +110,67 @@ def update_images(request, product_id):
 
     # Refresh positions
     for i, image in enumerate(product.images.all()):
-        image.position = i+1
+        image.position = (i + 1) * 10
         image.save()
 
     product_changed.send(product, request=request)
 
+    html = [["#images", manage_images(request, product_id, as_string=True)]]
     result = simplejson.dumps({
-        "images" : manage_images(request, product_id, as_string=True),
-        "message" : message,
-    }, cls = LazyEncoder)
+        "html": html,
+        "message": message,
+    }, cls=LazyEncoder)
 
     return HttpResponse(result)
 
+
+@permission_required("core.manage_shop", login_url="/login/")
+def move_image(request, id):
+    """Moves the image with passed id up or down.
+
+    **Parameters:**
+
+        id
+            The id of the image which should be edited.
+
+    **Query String:**
+
+        direction
+            The direction in which the image should be moved. One of 0 (up)
+            or 1 (down).
+
+    **Permission:**
+
+        edit (of the belonging content object)
+    """
+    image = Image.objects.get(pk=id)
+    product = image.content
+
+    direction = request.GET.get("direction", 0)
+
+    if direction == "1":
+        image.position += 15
+    else:
+        image.position -= 15
+        if image.position < 0:
+            image.position = 10
+
+    image.save()
+
+    # Refresh positions
+    for i, image in enumerate(product.images.all()):
+        image.position = (i + 1) * 10
+        image.save()
+
+    html = [["#images", manage_images(request, product.id, as_string=True)]]
+
+    result = simplejson.dumps({
+         "html": html,
+    }, cls=LazyEncoder)
+
+    return HttpResponse(result)
+
+
 @permission_required("core.manage_shop", login_url="/login/")
 def update_active_images(request, product_id):
     """Updates the images activity state for product variants.
@@ -127,6 +183,6 @@ def update_active_images(request, product_id):
     product.save()
 
     return lfs.core.utils.set_message_cookie(
-        url = reverse("lfs_manage_product", kwargs={"product_id": product.id}),
-        msg = _(u"Active images has been updated."),
+        url=reverse("lfs_manage_product", kwargs={"product_id": product.id}),
+        msg=_(u"Active images has been updated."),
     )
