@@ -19,6 +19,7 @@ from lfs.voucher.models import VoucherOptions
 from lfs.voucher.settings import ABSOLUTE
 from lfs.voucher.settings import PERCENTAGE
 
+
 class VoucherUtilsTestCase(TestCase):
     """
     """
@@ -37,10 +38,10 @@ class VoucherUtilsTestCase(TestCase):
         """Tests the custom options.
         """
         VoucherOptions.objects.create(
-            number_prefix = "DH",
-            number_suffix = "XM",
-            number_length = 4,
-            number_letters = "abcdefghijklmnopqrstuvwxyz",
+            number_prefix="DH",
+            number_suffix="XM",
+            number_length=4,
+            number_letters="abcdefghijklmnopqrstuvwxyz",
             )
 
         number = lfs.voucher.utils.create_voucher_number()
@@ -51,9 +52,12 @@ class VoucherUtilsTestCase(TestCase):
         for letter in number[2:-2]:
             self.failIf(letter not in letters)
 
+
 class VoucherTestCase(TestCase):
     """
     """
+    fixtures = ['lfs_shop.xml']
+
     def setUp(self):
         """
         """
@@ -63,18 +67,19 @@ class VoucherTestCase(TestCase):
 
         self.vg = VoucherGroup.objects.create(
             name="xmas",
-            creator = self.request.user,
+            creator=self.request.user,
         )
 
         self.v1 = Voucher.objects.create(
-            number = "AAAA",
-            group = self.vg,
-            creator = self.request.user,
-            start_date = datetime.date(2009, 12, 1),
-            end_date = datetime.date(2009, 12, 31),
-            effective_from = 0,
-            kind_of = ABSOLUTE,
-            value = 10.0,
+            number="AAAA",
+            group=self.vg,
+            creator=self.request.user,
+            start_date=datetime.date(2009, 12, 1),
+            end_date=datetime.date(2009, 12, 31),
+            effective_from=0,
+            kind_of=ABSOLUTE,
+            value=10.0,
+            limit=2,
         )
 
         self.p1 = Product.objects.create(name="Product 1", slug="product-1", price=10.0)
@@ -95,8 +100,8 @@ class VoucherTestCase(TestCase):
         self.assertEqual(self.v1.effective_from, 0.0)
         self.assertEqual(self.v1.kind_of, ABSOLUTE)
         self.assertEqual(self.v1.active, True)
-        self.assertEqual(self.v1.used, False)
-        self.assertEqual(self.v1.used_date, None)
+        self.assertEqual(self.v1.used_amount, 0)
+        self.assertEqual(self.v1.last_used_date, None)
         self.assertEqual(self.v1.value, 10.0)
         self.assertEqual(self.v1.tax, None)
 
@@ -104,26 +109,26 @@ class VoucherTestCase(TestCase):
         """
         """
         # No tax
-        price_net = self.v1.get_price_net()
+        price_net = self.v1.get_price_net(self.request)
         self.assertEqual(price_net, 10)
 
-        price_gross = self.v1.get_price_gross()
+        price_gross = self.v1.get_price_gross(self.request)
         self.assertEqual(price_gross, 10)
 
-        tax = self.v1.get_tax()
+        tax = self.v1.get_tax(self.request)
         self.assertEqual(tax, 0.0)
 
         # With tax
         self.v1.tax = Tax.objects.create(rate=19.0)
         self.v1.save()
 
-        price_net = self.v1.get_price_net()
+        price_net = self.v1.get_price_net(self.request)
         self.assertEqual("%.2f" % price_net, "%.2f" % 8.4)
 
-        price_gross = self.v1.get_price_gross()
+        price_gross = self.v1.get_price_gross(self.request)
         self.assertEqual(price_gross, 10)
 
-        tax = self.v1.get_tax()
+        tax = self.v1.get_tax(self.request)
         self.assertEqual("%.2f" % tax, "%.2f" % 1.6)
 
     def test_prices_percentage(self):
@@ -135,13 +140,13 @@ class VoucherTestCase(TestCase):
         self.v1.save()
 
         # No tax
-        price_gross = self.v1.get_price_gross(self.cart)
+        price_gross = self.v1.get_price_gross(self.request, self.cart)
         self.assertEqual(price_gross, 11.0)
 
-        price_net = self.v1.get_price_net(self.cart)
+        price_net = self.v1.get_price_net(self.request, self.cart)
         self.assertEqual(price_net, 11.0)
 
-        tax = self.v1.get_tax(self.cart)
+        tax = self.v1.get_tax(self.request, self.cart)
         self.assertEqual(tax, 0.0)
 
         # With tax
@@ -153,13 +158,13 @@ class VoucherTestCase(TestCase):
         self.p2.tax = tax
         self.p2.save()
 
-        price_gross = self.v1.get_price_gross(self.cart)
+        price_gross = self.v1.get_price_gross(self.request, self.cart)
         self.assertEqual(price_gross, 11.0)
 
-        price_net = self.v1.get_price_net(self.cart)
+        price_net = self.v1.get_price_net(self.request, self.cart)
         self.assertEqual("%.2f" % price_net, "%.2f" % 9.24)
 
-        tax = self.v1.get_tax(self.cart)
+        tax = self.v1.get_tax(self.request, self.cart)
         self.assertEqual("%.2f" % tax, "%.2f" % 1.76)
 
     def test_kind_of(self):
@@ -179,56 +184,66 @@ class VoucherTestCase(TestCase):
     def test_mark_as_used(self):
         """
         """
-        self.assertEqual(self.v1.used, False)
-        self.assertEqual(self.v1.used_date, None)
+        self.assertEqual(self.v1.used_amount, 0)
+        self.assertEqual(self.v1.last_used_date, None)
 
         self.v1.mark_as_used()
 
-        self.assertEqual(self.v1.used, True)
-        self.failIf(self.v1.used_date is None)
+        self.assertEqual(self.v1.used_amount, 1)
+        self.failIf(self.v1.last_used_date is None)
 
     def test_is_effective(self):
         """
         """
+        current_year = datetime.datetime.now().year
+
         # True
-        self.v1.start_date = datetime.date(2009, 1, 1)
-        self.v1.end_date = datetime.date(2009, 12, 31)
+        self.v1.start_date = datetime.date(2000, 1, 1)
+        self.v1.end_date = datetime.date(2999, 12, 31)
         self.v1.active = True
-        self.v1.used = False
+        self.v1.used_amount = 1
         self.v1.effective_from = 0
-        self.assertEqual(self.v1.is_effective(self.cart)[0], True)
+        self.assertEqual(self.v1.is_effective(self.request, self.cart)[0], True)
 
         # start / end
-        self.v1.start_date = datetime.date(2009, 12, 31)
-        self.v1.end_date = datetime.date(2009, 12, 31)
+        self.v1.start_date = datetime.date(current_year, 12, 31)
+        self.v1.end_date = datetime.date(current_year, 12, 31)
         self.v1.active = True
-        self.v1.used = False
+        self.v1.used_amount = 1
         self.v1.effective_from = 0
-        self.assertEqual(self.v1.is_effective(self.cart)[0], False)
+        self.assertEqual(self.v1.is_effective(self.request, self.cart)[0], False)
 
         # effective from
-        self.v1.start_date = datetime.date(2009, 1, 1)
-        self.v1.end_date = datetime.date(2009, 12, 31)
+        self.v1.start_date = datetime.date(current_year, 1, 1)
+        self.v1.end_date = datetime.date(current_year, 12, 31)
         self.v1.active = True
-        self.v1.used = False
+        self.v1.used_amount = 1
         self.v1.effective_from = 1000
-        self.assertEqual(self.v1.is_effective(self.cart)[0], False)
+        self.assertEqual(self.v1.is_effective(self.request, self.cart)[0], False)
 
         # Used
-        self.v1.start_date = datetime.date(2009, 1, 1)
-        self.v1.end_date = datetime.date(2009, 12, 31)
+        self.v1.start_date = datetime.date(current_year, 1, 1)
+        self.v1.end_date = datetime.date(current_year, 12, 31)
         self.v1.active = True
-        self.v1.used = True
+        self.v1.used_amount = 1
         self.v1.effective_from = 0
-        self.assertEqual(self.v1.is_effective(self.cart)[0], False)
+        self.assertEqual(self.v1.is_effective(self.request, self.cart)[0], True)
+
+        self.v1.mark_as_used()
+        self.assertEqual(self.v1.is_effective(self.request, self.cart)[0], False)
+
+        # unlimited amount
+        self.v1.limit = 0
+        self.assertEqual(self.v1.is_effective(self.request, self.cart)[0], True)
 
         # Not active
-        self.v1.start_date = datetime.date(2009, 1, 1)
-        self.v1.end_date = datetime.date(2009, 12, 31)
+        self.v1.start_date = datetime.date(current_year, 1, 1)
+        self.v1.end_date = datetime.date(current_year, 12, 31)
         self.v1.active = False
-        self.v1.used = False
+        self.v1.used_amount = 1
         self.v1.effective_from = 0
-        self.assertEqual(self.v1.is_effective(self.cart)[0], False)
+        self.assertEqual(self.v1.is_effective(self.request, self.cart)[0], False)
+
 
 class VoucherOptionsCase(TestCase):
     """
